var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { get } from 'lodash-es';
import { Query } from '../query';
import { NetworkError } from '../errors/network';
import { KinveyError } from '../errors/kinvey';
import { Aggregation } from '../aggregation';
import { DataStoreCache } from './cache';
import { NetworkStore } from './networkstore';
import { CacheStore } from './cachestore';
export class AutoStore extends CacheStore {
    constructor(collectionName, options = { tag: undefined, useDeltaSet: false, useAutoPagination: false }) {
        super(collectionName, options);
    }
    find(query, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            if (query && !(query instanceof Query)) {
                throw new KinveyError('query is not an instance of the Query class.');
            }
            const cache = new DataStoreCache(this.collectionName, this.tag);
            const useDeltaSet = options.useDeltaSet === true || this.useDeltaSet;
            query = query && new Query(query.toPlainObject());
            try {
                if (useDeltaSet) {
                    yield this.pull(query, options);
                    return yield cache.find(query);
                }
                const requiredFields = get(query, 'fields', []);
                if (query) {
                    query.fields = [];
                }
                const serverResponse = yield this._pullInternal(query, options);
                if (!requiredFields.length) {
                    return serverResponse;
                }
                return new Query({ fields: requiredFields }).process(serverResponse);
            }
            catch (error) {
                if (error instanceof NetworkError) {
                    return cache.find(query);
                }
                throw error;
            }
        });
    }
    count(query, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            if (query && !(query instanceof Query)) {
                throw new KinveyError('query is not an instance of the Query class.');
            }
            try {
                const network = new NetworkStore(this.collectionName);
                const count = yield network.count(query, options).toPromise();
                return count;
            }
            catch (error) {
                if (error instanceof NetworkError) {
                    const cache = new DataStoreCache(this.collectionName, this.tag);
                    return cache.count(query);
                }
                throw error;
            }
        });
    }
    group(aggregation, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!(aggregation instanceof Aggregation)) {
                throw new KinveyError('aggregation is not an instance of the Aggregation class.');
            }
            try {
                const network = new NetworkStore(this.collectionName);
                const result = yield network.group(aggregation, options).toPromise();
                return result;
            }
            catch (error) {
                if (error instanceof NetworkError) {
                    const cache = new DataStoreCache(this.collectionName, this.tag);
                    return cache.group(aggregation);
                }
                throw error;
            }
        });
    }
    findById(id, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const cache = new DataStoreCache(this.collectionName, this.tag);
            try {
                const doc = yield this.pullById(id, options);
                return doc;
            }
            catch (error) {
                if (error instanceof NetworkError) {
                    return cache.findById(id);
                }
                throw error;
            }
        });
    }
}
//# sourceMappingURL=autostore.js.map