import { isString } from 'lodash-es';
import { Storage } from '../storage';
import { getAppKey } from '../kinvey';
const QUERY_CACHE_TAG = '_QueryCache';
const SYNC_CACHE_TAG = 'kinvey_sync';
export function isValidTag(tag) {
    const regexp = /^[a-z0-9-]+$/i;
    return isString(tag) && regexp.test(tag);
}
export class DataStoreCache extends Storage {
    constructor(collectionName, tag) {
        if (tag && !isValidTag(tag)) {
            throw new Error('A tag can only contain letters, numbers, and "-".');
        }
        if (tag) {
            super(getAppKey(), `${collectionName}.${tag}`);
        }
        else {
            super(getAppKey(), collectionName);
        }
    }
    static clear() {
        return Storage.clear(getAppKey());
    }
}
export class QueryCache extends DataStoreCache {
    constructor(tag) {
        super(QUERY_CACHE_TAG, tag);
    }
}
export var SyncEvent;
(function (SyncEvent) {
    SyncEvent["Create"] = "POST";
    SyncEvent["Update"] = "PUT";
    SyncEvent["Delete"] = "DELETE";
})(SyncEvent || (SyncEvent = {}));
;
export class SyncCache extends DataStoreCache {
    constructor(tag) {
        super(SYNC_CACHE_TAG, tag);
    }
}
//# sourceMappingURL=cache.js.map