var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { isNumber } from 'lodash-es';
import { Query } from '../query';
import { KinveyError } from '../errors/kinvey';
import { KinveyHttpRequest, HttpRequestMethod, KinveyHttpAuth, formatKinveyBaasUrl, KinveyBaasNamespace } from '../http';
import { downloadByUrl } from './downloadByUrl';
export function find(query = new Query(), options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const { download = false, tls = true, ttl } = options;
        let queryStringObject = Object.assign({}, { tls: tls === true });
        if (query) {
            if (!(query instanceof Query)) {
                throw new KinveyError('Invalid query. It must be an instance of the Query class.');
            }
            queryStringObject = Object.assign({}, queryStringObject, query.toQueryObject());
        }
        if (isNumber(ttl)) {
            queryStringObject.ttl_in_seconds = ttl;
        }
        const request = new KinveyHttpRequest({
            method: HttpRequestMethod.GET,
            auth: KinveyHttpAuth.SessionOrMaster,
            url: formatKinveyBaasUrl(KinveyBaasNamespace.Blob, '/', queryStringObject),
            timeout: options.timeout
        });
        const response = yield request.execute();
        const files = response.data;
        if (download === true) {
            return Promise.all(files.map((file) => downloadByUrl(file._downloadURL, options)));
        }
        return files;
    });
}
//# sourceMappingURL=find.js.map