import { HttpHeaders, KinveyHttpHeaders, KinveyHttpAuth } from './headers';
import { HttpResponse } from './response';
export declare enum HttpRequestMethod {
    GET = "GET",
    POST = "POST",
    PUT = "PUT",
    DELETE = "DELETE"
}
export interface HttpRequestConfig {
    headers?: HttpHeaders;
    method: HttpRequestMethod;
    url: string;
    body?: string | object;
    timeout?: number;
}
export declare function serialize(contentType: string, body?: any): any;
export declare class HttpRequest {
    headers: HttpHeaders;
    method: HttpRequestMethod;
    url: string;
    body?: any;
    timeout?: number;
    constructor(config: HttpRequestConfig);
    execute(): Promise<HttpResponse>;
    toPlainObject(): {
        headers: {
            [name: string]: string;
        };
        method: HttpRequestMethod;
        url: string;
        body: any;
        timeout: number;
    };
}
export interface KinveyHttpRequestConfig extends HttpRequestConfig {
    headers?: KinveyHttpHeaders;
    auth?: KinveyHttpAuth;
}
export declare class KinveyHttpRequest extends HttpRequest {
    headers: KinveyHttpHeaders;
    auth?: KinveyHttpAuth;
    constructor(config: KinveyHttpRequestConfig);
    _refreshMICSession(micSession: any): Promise<boolean>;
    execute(retry?: boolean): Promise<HttpResponse>;
}
