var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { get } from 'lodash-es';
import { ConfigKey, getConfig } from '../config';
import { getAppKey } from '../kinvey';
function getStore() {
    return getConfig(ConfigKey.SessionStore);
}
export function getKey() {
    return `${getAppKey()}.active_user`;
}
function _getObjectFromStore(key) {
    return __awaiter(this, void 0, void 0, function* () {
        const obj = yield getStore().get(key);
        if (!obj) {
            return null;
        }
        return JSON.parse(obj);
    });
}
export function getSession() {
    return __awaiter(this, void 0, void 0, function* () {
        return _getObjectFromStore(getKey());
    });
}
function _setObjectInStore(key, obj) {
    return __awaiter(this, void 0, void 0, function* () {
        return getStore().set(key, JSON.stringify(obj));
    });
}
export function setSession(session) {
    return __awaiter(this, void 0, void 0, function* () {
        return _setObjectInStore(getKey(), session);
    });
}
export function removeSession() {
    return __awaiter(this, void 0, void 0, function* () {
        return getStore().remove(getKey());
    });
}
function getMFAKey() {
    return `${getAppKey()}.mfa_user`;
}
export function getMFASession() {
    return __awaiter(this, void 0, void 0, function* () {
        return _getObjectFromStore(getMFAKey());
    });
}
export function getMFASessionToken() {
    return __awaiter(this, void 0, void 0, function* () {
        const mfaUser = yield getMFASession();
        if (!mfaUser) {
            return null;
        }
        return mfaUser.mfaSessionToken;
    });
}
export function setMFASession(mfaSession) {
    return __awaiter(this, void 0, void 0, function* () {
        return _setObjectInStore(getMFAKey(), mfaSession);
    });
}
export function removeMFASession() {
    return __awaiter(this, void 0, void 0, function* () {
        return getStore().remove(getMFAKey());
    });
}
function getDeviceTokenKey(username) {
    return `${getAppKey()}.${username}.device_token`;
}
export function getDeviceToken(username) {
    return __awaiter(this, void 0, void 0, function* () {
        return getStore().get(getDeviceTokenKey(username));
    });
}
export function hasDeviceToken(username) {
    return __awaiter(this, void 0, void 0, function* () {
        const deviceToken = yield getDeviceToken(username);
        return deviceToken != null;
    });
}
export function setDeviceToken(username, deviceToken) {
    return __awaiter(this, void 0, void 0, function* () {
        return getStore().set(getDeviceTokenKey(username), deviceToken);
    });
}
export function removeDeviceToken(username) {
    return __awaiter(this, void 0, void 0, function* () {
        return getStore().remove(getDeviceTokenKey(username));
    });
}
export function getKinveyMICSession() {
    return __awaiter(this, void 0, void 0, function* () {
        const session = yield getSession();
        return get(session, '_socialIdentity.kinveyAuth', null);
    });
}
export function setKinveyMICSession(newKinveyMICSession) {
    return __awaiter(this, void 0, void 0, function* () {
        const existingKinveyMICSession = yield getKinveyMICSession();
        if (!existingKinveyMICSession) {
            return false;
        }
        const existingSession = yield getSession();
        const mergedMICSession = Object.assign({}, existingSession._socialIdentity.kinveyAuth, newKinveyMICSession);
        existingSession._socialIdentity.kinveyAuth = mergedMICSession;
        return setSession(existingSession);
    });
}
//# sourceMappingURL=session.js.map