import { format } from 'url';
import urlJoin from 'url-join';
import { isPlainObject } from 'lodash-es';
import { getBaasProtocol, getBaasHost, getAuthProtocol, getAuthHost, getAppKey } from '../kinvey';
function clean(value) {
    return Object.keys(value)
        .reduce((cleanVal, key) => {
        let objVal = value[key];
        if (isPlainObject(objVal)) {
            objVal = clean(objVal);
        }
        if (typeof objVal !== 'undefined' && objVal !== null) {
            cleanVal[key] = objVal;
        }
        return cleanVal;
    }, {});
}
export var KinveyBaasNamespace;
(function (KinveyBaasNamespace) {
    KinveyBaasNamespace["AppData"] = "appdata";
    KinveyBaasNamespace["Blob"] = "blob";
    KinveyBaasNamespace["Push"] = "push";
    KinveyBaasNamespace["Rpc"] = "rpc";
    KinveyBaasNamespace["User"] = "user";
})(KinveyBaasNamespace || (KinveyBaasNamespace = {}));
export function formatKinveyBaasUrl(namespace, path, query) {
    return format({
        protocol: getBaasProtocol(),
        host: getBaasHost(),
        pathname: path ? urlJoin(namespace, getAppKey(), path) : urlJoin(namespace, getAppKey()),
        query: query ? clean(query) : undefined
    });
}
export function formatKinveyAuthUrl(path, query) {
    return format({
        protocol: getAuthProtocol(),
        host: getAuthHost(),
        pathname: path,
        query: query ? clean(query) : undefined
    });
}
//# sourceMappingURL=utils.js.map