var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { getActiveUser } from '../user/getActiveUser';
import { createMFAAuthenticator, } from '../user/createMFAAuthenticator';
import { KinveyError } from '../errors/kinvey';
import { getMFASession } from '../http';
function callOnActiveUser(funcName, ...args) {
    return __awaiter(this, void 0, void 0, function* () {
        const activeUser = yield getActiveUser();
        if (!activeUser) {
            throw new KinveyError('An active user does not exist. Please login one first.');
        }
        return activeUser[funcName](...args);
    });
}
const Authenticators = {
    create: function create(newAuthenticator, verify) {
        return __awaiter(this, void 0, void 0, function* () {
            const activeUser = yield getActiveUser();
            if (activeUser) {
                return createMFAAuthenticator(activeUser.data._id, newAuthenticator, verify);
            }
            const mfaUser = yield getMFASession();
            if (!mfaUser) {
                throw new KinveyError('An active user, nor an MFA user exists. Please login one first.');
            }
            return createMFAAuthenticator(mfaUser.userId, newAuthenticator, verify);
        });
    },
    list: function list() {
        return callOnActiveUser('listAuthenticators');
    },
    remove: function remove(id) {
        return callOnActiveUser('removeAuthenticator', id);
    },
};
function listRecoveryCodes() {
    return callOnActiveUser('listRecoveryCodes');
}
function regenerateRecoveryCodes() {
    return callOnActiveUser('regenerateRecoveryCodes');
}
function isEnabled() {
    return __awaiter(this, void 0, void 0, function* () {
        return callOnActiveUser('isMFAEnabled');
    });
}
function disable() {
    return __awaiter(this, void 0, void 0, function* () {
        return callOnActiveUser('disableMFA');
    });
}
export { Authenticators, listRecoveryCodes, regenerateRecoveryCodes, isEnabled, disable };
//# sourceMappingURL=index.js.map