var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { pick, defaults } from 'lodash-es';
import { KinveyError } from '../errors';
import { formatKinveyBaasUrl, HttpRequestMethod, KinveyBaasNamespace, KinveyHttpAuth, KinveyHttpRequest, } from '../http';
export var MFAAuthenticatorType;
(function (MFAAuthenticatorType) {
    MFAAuthenticatorType["TOTP"] = "totp";
})(MFAAuthenticatorType || (MFAAuthenticatorType = {}));
function _verifyAuthenticatorRetryable(userId, verify, context, maxRetriesCount) {
    return __awaiter(this, void 0, void 0, function* () {
        if (context.retries >= maxRetriesCount) {
            throw new KinveyError('Max retries count for authenticator verification exceeded.');
        }
        const code = yield verify(context.authenticator, context);
        if (code == null) {
            throw new KinveyError('MFA code is missing.');
        }
        try {
            const request = new KinveyHttpRequest({
                method: HttpRequestMethod.POST,
                auth: KinveyHttpAuth.SessionOrMFASessionTokenOrMaster,
                url: formatKinveyBaasUrl(KinveyBaasNamespace.User, `/${userId}/authenticators/${context.authenticator.id}/verify`),
                body: { code },
            });
            const { data } = yield request.execute();
            return data;
        }
        catch (err) {
            context.retries += 1; // eslint-disable-line no-param-reassign
            context.error = err; // eslint-disable-line no-param-reassign
            return _verifyAuthenticatorRetryable(userId, verify, context, maxRetriesCount);
        }
    });
}
export function createMFAAuthenticator(userId, newAuthenticator, verify) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!verify) {
            throw new KinveyError('Function to verify authenticator is missing.');
        }
        const request = new KinveyHttpRequest({
            method: HttpRequestMethod.POST,
            auth: KinveyHttpAuth.SessionOrMFASessionTokenOrMaster,
            url: formatKinveyBaasUrl(KinveyBaasNamespace.User, `/${userId}/authenticators`),
            body: defaults(newAuthenticator, { type: MFAAuthenticatorType.TOTP }),
        });
        const { data: authenticator } = yield request.execute();
        const verifyResult = yield _verifyAuthenticatorRetryable(userId, verify, { authenticator, retries: 0 }, 10);
        return {
            authenticator: pick(authenticator, ['id', 'name', 'type', 'config']),
            recoveryCodes: verifyResult.recoveryCodes || null,
        };
    });
}
//# sourceMappingURL=createMFAAuthenticator.js.map