var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { has, unset } from 'lodash-es';
import { ActiveUserError } from '../errors/activeUser';
import { KinveyError } from '../errors/kinvey';
import { setSession, formatKinveyBaasUrl, HttpRequestMethod, KinveyHttpRequest, KinveyBaasNamespace, KinveyHttpAuth } from '../http';
import { getActiveUser } from './getActiveUser';
import { User } from './user';
export function validateNoActiveUser() {
    return __awaiter(this, void 0, void 0, function* () {
        const activeUser = yield getActiveUser();
        if (activeUser) {
            throw new ActiveUserError('An active user already exists. Please logout the active user before you login.');
        }
    });
}
export function executeLoginRequest(reqBody, timeout) {
    return __awaiter(this, void 0, void 0, function* () {
        const request = new KinveyHttpRequest({
            method: HttpRequestMethod.POST,
            auth: KinveyHttpAuth.App,
            url: formatKinveyBaasUrl(KinveyBaasNamespace.User, '/login'),
            body: reqBody,
            timeout
        });
        const response = yield request.execute();
        const { data } = response;
        // Remove sensitive data
        unset(data, 'password');
        unset(data, 'user.password');
        if (!has(data, 'mfaRequired')) {
            return {
                mfaRequired: false,
                user: data,
            };
        }
        if (!data.mfaRequired) {
            data.user._kmd.authtoken = data.authToken;
        }
        return data;
    });
}
export function validateCredentials(username, password) {
    const credentials = { username, password };
    if (credentials.username) {
        credentials.username = String(credentials.username).trim();
    }
    if (credentials.password) {
        credentials.password = String(credentials.password).trim();
    }
    if (!credentials.username || credentials.username === '' || !credentials.password || credentials.password === '') {
        throw new KinveyError('Username and/or password missing. Please provide both a username and password to login.');
    }
    return credentials;
}
export function login(username, password, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        yield validateNoActiveUser();
        const credentials = validateCredentials(username, password);
        const result = yield executeLoginRequest(credentials, options.timeout);
        if (result.mfaRequired) {
            throw new KinveyError('MFA login is required.');
        }
        const { user } = result;
        yield setSession(user);
        return new User(user);
    });
}
//# sourceMappingURL=login.js.map