var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { isString } from 'lodash-es';
import { ActiveUserError } from '../errors/activeUser';
import { NotFoundError } from '../errors/notFound';
import { KinveyError } from '../errors/kinvey';
import { getAppKey } from '../kinvey';
import { getTokenWithUsernamePassword } from './mic';
import { signup } from './signup';
import { getActiveUser } from './getActiveUser';
import { loginWithSocialIdentity } from "./loginWithSocialIdentity";
export function loginWithMICUsingResourceOwnerCredentials(username, password, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const activeUser = yield getActiveUser();
        const { micId } = options;
        let clientId = getAppKey();
        if (activeUser) {
            throw new ActiveUserError('An active user already exists. Please logout the active user before you login with Mobile Identity Connect.');
        }
        if (!isString(username) || !isString(password)) {
            throw new KinveyError('A username and password are required and must be a string.');
        }
        if (isString(micId)) {
            clientId = `${clientId}.${micId}`;
        }
        const token = yield getTokenWithUsernamePassword(username, password, clientId, options);
        const socialIdentity = { [token.identity]: token };
        const credentials = { _socialIdentity: socialIdentity };
        try {
            return yield loginWithSocialIdentity(socialIdentity);
        }
        catch (error) {
            if (error instanceof NotFoundError) {
                return yield signup(credentials);
            }
            throw error;
        }
    });
}
//# sourceMappingURL=loginWithMICUsingResourceOwnerCredentials.js.map