var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { trim } from 'lodash-es';
import { KinveyError } from '../errors/kinvey';
import { setSession } from '../http';
import { User } from './user';
import { validateNoActiveUser, executeLoginRequest, validateCredentials } from './login';
export function loginWithRecoveryCode(username, password, recoveryCode, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        yield validateNoActiveUser();
        const credentials = validateCredentials(username, password);
        const trimmedCode = trim(recoveryCode);
        if (trimmedCode === '') {
            throw new KinveyError('Recovery code is missing.');
        }
        credentials.recoveryCode = trimmedCode;
        const loginResult = yield executeLoginRequest(credentials, options.timeout);
        yield setSession(loginResult.user);
        return new User(loginResult.user);
    });
}
//# sourceMappingURL=loginWithRecoveryCode.js.map