var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Base64 } from 'js-base64';
import { formatKinveyAuthUrl, HttpRequestMethod, KinveyHttpRequest, KinveyHttpHeaders } from '../../http';
import { getAuthProtocol, getAuthHost, getAppSecret } from '../../kinvey';
import { Identity, getVersion } from './utils';
// export interface Token {
//   identity: string;
//   client_id: string;
//   redirect_uri: string;
//   protocol: string;
//   host: string;
// }
export function getTokenWithCode(code, clientId, redirectUri, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const request = new KinveyHttpRequest({
            method: HttpRequestMethod.POST,
            headers: new KinveyHttpHeaders({
                'Content-Type': () => 'application/x-www-form-urlencoded',
                Authorization: () => {
                    const credentials = Base64.encode(`${clientId}:${getAppSecret()}`);
                    return `Basic ${credentials}`;
                }
            }),
            url: formatKinveyAuthUrl(`/${getVersion(options.version)}/oauth/token`),
            body: {
                grant_type: 'authorization_code',
                client_id: clientId,
                redirect_uri: redirectUri,
                code
            },
            timeout: options.timeout
        });
        const response = yield request.execute();
        const token = response.data;
        return Object.assign({}, {
            identity: Identity,
            client_id: clientId,
            redirect_uri: redirectUri,
            protocol: getAuthProtocol(),
            host: getAuthHost()
        }, token);
    });
}
//# sourceMappingURL=getTokenWithCode.js.map