var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { parse } from 'url';
import { formatKinveyAuthUrl } from '../../http';
import { KinveyError } from '../../errors/kinvey';
import { getVersion } from './utils';
import { open } from './popup';
export function loginWithPopup(clientId, redirectUri, version) {
    return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
        const url = formatKinveyAuthUrl(`/${getVersion(version)}/oauth/auth`, {
            client_id: clientId,
            redirect_uri: redirectUri,
            response_type: 'code',
            scope: 'openid'
        });
        const popup = yield open(url);
        let redirected = false;
        popup.onLoaded((event) => __awaiter(this, void 0, void 0, function* () {
            try {
                if (event.url && event.url.indexOf(redirectUri) === 0 && redirected === false) {
                    const parsedUrl = parse(event.url, true);
                    const { code, error, error_description } = parsedUrl.query;
                    redirected = true;
                    popup.removeAllListeners();
                    yield popup.close();
                    if (code) {
                        resolve(code);
                    }
                    else if (error) {
                        reject(new KinveyError(error));
                    }
                    else {
                        reject(new KinveyError('No code or error was provided.'));
                    }
                }
            }
            catch (error) {
                // Just catch the error
            }
        }));
        popup.onClosed(() => {
            if (!redirected) {
                popup.removeAllListeners();
                reject(new KinveyError('Login has been cancelled.'));
            }
        });
    }));
}
//# sourceMappingURL=loginWithPopup.js.map