var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { isString } from 'lodash-es';
import { KinveyError } from '../errors/kinvey';
import { formatKinveyBaasUrl, HttpRequestMethod, KinveyHttpRequest, KinveyBaasNamespace, KinveyHttpAuth } from '../http';
import { getActiveUser } from './getActiveUser';
export function remove(id, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        const { hard } = options;
        const activeUser = yield getActiveUser();
        if (!id) {
            throw new KinveyError('An id was not provided.');
        }
        if (!isString(id)) {
            throw new KinveyError('The id provided is not a string.');
        }
        // Remove the user from the backend
        const url = formatKinveyBaasUrl(KinveyBaasNamespace.User, `/${id}`, { hard: hard ? hard === true : undefined });
        const request = new KinveyHttpRequest({
            method: HttpRequestMethod.DELETE,
            auth: KinveyHttpAuth.Master,
            url,
            timeout: options.timeout
        });
        const response = yield request.execute();
        // Logout the active user if it is the user we removed
        if (activeUser && activeUser._id === id) {
            yield activeUser.logout();
        }
        // Return the response
        return response.data;
    });
}
//# sourceMappingURL=remove.js.map