import { Acl } from '../acl';
import { Kmd } from '../kmd';
import { Entity } from '../storage';
import { CreateMFAAuthenticatorResult, MFAAuthenticator, NewMFAAuthenticator, VerifyContext } from './createMFAAuthenticator';
export interface UserData extends Entity {
    _socialIdentity?: object;
    username?: string;
    email?: string;
}
export declare class User {
    data: UserData;
    constructor(data?: UserData);
    get _id(): string;
    get _acl(): Acl;
    get _kmd(): Kmd;
    get metadata(): Kmd;
    get authtoken(): string;
    get _socialIdentity(): object;
    get username(): string;
    get email(): string;
    isActive(): Promise<boolean>;
    isEmailVerified(): boolean;
    signup(options?: {
        timeout?: number;
        state?: boolean;
    }): Promise<User>;
    me(options?: {
        timeout?: number;
    }): Promise<this>;
    update(data: object, options?: {
        timeout?: number;
    }): Promise<this>;
    registerForLiveService(options?: {
        timeout?: number;
    }): Promise<boolean>;
    unregisterFromLiveService(options?: {
        timeout?: number;
    }): Promise<boolean>;
    createAuthenticator(newAuthenticator: NewMFAAuthenticator, verify: (authenticator: MFAAuthenticator, context: VerifyContext) => Promise<string>): Promise<CreateMFAAuthenticatorResult>;
    listAuthenticators(): Promise<MFAAuthenticator[]>;
    removeAuthenticator(id: string): Promise<any>;
    listRecoveryCodes(): Promise<string[]>;
    regenerateRecoveryCodes(): Promise<string[]>;
    isMFAEnabled(): Promise<boolean>;
    disableMFA(): Promise<any>;
    _cleanup(kinveyRequest: any, operationName: any, cleanEntireSessionStore?: boolean): Promise<this>;
    logout(options?: {
        timeout?: number;
    }): Promise<this>;
    invalidateTokens(): Promise<this>;
}
